@@ -12,7 +12,7 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                           }....................
-from beartype._util.text.utiltextmunge import trim_object_repr
+from beartype._util.text.utiltextrepr import get_object_representation
 
 # See the "beartype.__init__" submodule for further commentary.
 __all__ = ['STAR_IMPORTS_CONSIDERED_HARMFUL']
@@ -42,11 +42,42 @@ def label_callable_decorated(func: 'CallableTypes') -> None:
     # Create and return this label.
     return '@beartyped ' + func.__name__ + '()'
 
+
+def label_callable_decorated_pith(
+    func: 'CallableTypes', pith_name: str) -> None:
+    '''
+    Human-readable label describing either the parameter with the passed name
+    *or* return value if this name is ``return`` of the passed **decorated
+    callable** (i.e., callable wrapped by the :func:`beartype.beartype`
+    decorator with a wrapper function type-checking that callable).
+
+    Parameters
+    ----------
+    func : CallableTypes
+        Decorated callable to be labelled.
+    pith_name : str
+        Name of the parameter or return value of this callable to be labelled.
+
+    Returns
+    ----------
+    str
+        Human-readable label describing either the name of this parameter *or*
+        this return value.
+    '''
+    assert isinstance(pith_name, str), '{!r} not string.'.format(pith_name)
+
+    # Return a human-readable label describing either...
+    return (
+        # If this name is "return", the return value of this callable.
+        label_callable_decorated_return(func)
+        if pith_name == 'return' else
+        # Else, the parameter with this name of this callable.
+        label_callable_decorated_param(func=func, param_name=pith_name)
+    )
+
 # ....................{ LABELLERS ~ param                 }....................
 def label_callable_decorated_param(
-    func: 'CallableTypes',
-    param_name: str,
-) -> None:
+    func: 'CallableTypes', param_name: str) -> None:
     '''
     Human-readable label describing the parameter with the passed name of the
     passed **decorated callable** (i.e., callable wrapped by the
@@ -65,8 +96,7 @@ def label_callable_decorated_param(
     str
         Human-readable label describing this parameter's name.
     '''
-    assert isinstance(param_name, str), (
-        'Parameter name {!r} not string.'.format(param_name))
+    assert isinstance(param_name, str), '{!r} not string.'.format(param_name)
 
     #FIXME: Refactor to leverage f-strings after dropping Python 3.5 support,
     #which are the optimal means of performing string formatting.
@@ -77,10 +107,7 @@ def label_callable_decorated_param(
 
 
 def label_callable_decorated_param_value(
-    func: 'CallableTypes',
-    param_name: str,
-    param_value: object,
-) -> None:
+    func: 'CallableTypes', param_name: str, param_value: object) -> None:
     '''
     Human-readable label describing the parameter with the passed name and
     trimmed value of the passed **decorated callable** (i.e., callable wrapped
@@ -101,8 +128,7 @@ def label_callable_decorated_param_value(
     str
         Human-readable label describing this parameter's name and value.
     '''
-    assert isinstance(param_name, str), (
-        'Parameter name {!r} not string.'.format(param_name))
+    assert isinstance(param_name, str), '{!r} not string.'.format(param_name)
 
     #FIXME: Refactor to leverage f-strings after dropping Python 3.5 support,
     #which are the optimal means of performing string formatting.
@@ -111,7 +137,7 @@ def label_callable_decorated_param_value(
     return '{} parameter {}={}'.format(
         label_callable_decorated(func),
         param_name,
-        trim_object_repr(param_value),
+        get_object_representation(param_value),
     )
 
 # ....................{ LABELLERS ~ return                }....................
@@ -133,7 +159,7 @@ def label_callable_decorated_return(func: 'CallableTypes') -> None:
     '''
 
     # Create and return this label.
-    return label_callable_decorated(func) + ' return'
+    return label_callable_decorated(func) + ' return value'
 
 
 def label_callable_decorated_return_value(
@@ -162,4 +188,5 @@ def label_callable_decorated_return_value(
 
     # Create and return this label.
     return '{} {}'.format(
-        label_callable_decorated_return(func), trim_object_repr(return_value))
+        label_callable_decorated_return(func),
+        get_object_representation(return_value))
