@@ -15,8 +15,8 @@ This submodule unit tests the public API of the :mod:`beartype.cave` submodule.
 # package-specific submodules at module scope.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-import argparse, functools, pytest, re, sys, weakref
-from beartype_test.util.mark.pytest_skip import (
+import argparse, functools, re, sys, weakref
+from beartype_test.util.mark.pytskip import (
     skip_if_pypy,
     skip_if_python_version_less_than,
     skip_unless_module,
@@ -24,8 +24,9 @@ from beartype_test.util.mark.pytest_skip import (
 from collections import deque
 from collections.abc import Iterable
 from decimal import Decimal
-from fractions import Fraction
 from enum import Enum
+from fractions import Fraction
+from pytest import raises
 
 # ....................{ TODO                              }....................
 #FIXME: Unit test the following types, which remain untested for the initial
@@ -674,7 +675,10 @@ def test_api_cave_tuple_nonetypeor() -> None:
     # from beartype import cave
     from beartype.cave import (
         AnyType, CallableTypes, MappingMutableType, NoneType, NoneTypeOr)
-    from beartype.roar import BeartypeCaveNoneTypeOrKeyException
+    from beartype.roar import (
+        BeartypeCaveNoneTypeOrKeyException,
+        BeartypeCaveNoneTypeOrMutabilityException,
+    )
 
     # Assert this factory to be a mutable mapping.
     assert isinstance(NoneTypeOr, MappingMutableType)
@@ -682,12 +686,13 @@ def test_api_cave_tuple_nonetypeor() -> None:
     # Assert this factory to be initially empty.
     assert not NoneTypeOr
 
-    # Assert this factory to *NOT* be indexable by arbitrary objects that are
-    # neither types nor tuples of types.
-    with pytest.raises(BeartypeCaveNoneTypeOrKeyException):
-        NoneTypeOr['If you can dream--and not make dreams your master;']
-    with pytest.raises(BeartypeCaveNoneTypeOrKeyException):
-        NoneTypeOr[('If you can think--and not make thoughts your aim;',)]
+    # Avoid asserting this factory to be indexable or *NOT* indexable by
+    # various types, as the existing test_utilhint_die_unless_hint_nonpep()
+    # unit test already exercises these edge cases.
+    #
+    # Assert this factory to *NOT* be explicitly settable.
+    with raises(BeartypeCaveNoneTypeOrMutabilityException):
+        NoneTypeOr['If you can meet with'] = 'Triumph and Disaster'
 
     # Assert that indexing this factory with "NoneType" creates, caches, and
     # returns a tuple containing only "NoneType".
